[![CircleCI](https://circleci.com/gh/experimaestro/datamaestro_ml.svg?style=svg)](https://circleci.com/gh/experimaestro/datamaestro) [![PyPI version](https://badge.fury.io/py/datamaestro-ml.svg)](https://badge.fury.io/py/datamaestro-ml)

# Image-related datasets

This [datamaestro](https://github.com/bpiwowar/datasets) plugin covers machine-learning related datasets (general purpose). 

## List of available datasets

Below is the list of available datasets along with ids. Some datasets have several versions; in this case, the dataset id is suffixed with this information.

- Boston housing (UCI)